.. image:: https://img.shields.io/pypi/v/pinkman.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/pinkman/
.. image:: https://github.com/norwik/pinkman/actions/workflows/ci.yml/badge.svg
    :alt: Build Status
    :target: https://github.com/norwik/pinkman/actions/workflows/ci.yml

|

=======
Pinkman
=======

An SMTP Server to forward Messages into Orangutan.

To use pinkman, follow the following steps:

1. Create a python virtual environment or use system wide environment

.. code-block::

    $ python3 -m venv venv
    $ source venv/bin/activate


2. Install pinkman package with pip.

.. code-block::

    $ pip install pinkman


3. Get pinkman command line help

.. code-block::

    $ pinkman --help
